<?php

namespace Drupal\crm\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\crm\CrmEmailTypeInterface;

/**
 * Defines the email type entity type.
 *
 * @ConfigEntityType(
 *   id = "crm_email_type",
 *   label = @Translation("Email Type"),
 *   label_collection = @Translation("Email Types"),
 *   label_singular = @Translation("email type"),
 *   label_plural = @Translation("email types"),
 *   label_count = @PluralTranslation(
 *     singular = "@count email type",
 *     plural = "@count email types",
 *   ),
 *   handlers = {
 *     "list_builder" = "Drupal\crm\EmailTypeListBuilder",
 *     "form" = {
 *       "add" = "Drupal\crm\Form\EmailTypeForm",
 *       "edit" = "Drupal\crm\Form\EmailTypeForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     }
 *   },
 *   config_prefix = "crm_email_type",
 *   admin_permission = "administer crm_email_type",
 *   links = {
 *     "collection" = "/admin/structure/crm-email-type",
 *     "add-form" = "/admin/structure/crm-email-type/add",
 *     "edit-form" = "/admin/structure/crm-email-type/{crm_email_type}",
 *     "delete-form" = "/admin/structure/crm-email-type/{crm_email_type}/delete"
 *   },
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "description"
 *   }
 * )
 */
class EmailType extends ConfigEntityBase implements CrmEmailTypeInterface {

  /**
   * The email type ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The email type label.
   *
   * @var string
   */
  protected $label;

  /**
   * The email type status.
   *
   * @var bool
   */
  protected $status;

  /**
   * The crm_email_type description.
   *
   * @var string
   */
  protected $description;

}
